@@ -155,8 +155,7 @@ namespace gum {
     /**
      * This operator compares 2 BNs !
      * @warning To identify nodes between BNs, it is assumed that they share the
-     *same
-     *name.
+     *same name.
      *
      * @return true if the src and this are equal.
      */
@@ -212,6 +211,25 @@ namespace gum {
 
     /// @return Returns a string representation of this IBayesNet.
     std::string toString( void ) const;
+
+    /***
+     * @return the minimal subset of soids that conditions the target
+     *
+     * i.e. P(target| soids)=P(target|@return)
+     */
+    NodeSet minimalCondSet( NodeId target, const NodeSet& soids ) const;
+
+    private:
+    void __minimalCondSetVisitUp( NodeId         node,
+                                  const NodeSet& soids,
+                                  NodeSet&       minimal,
+                                  NodeSet&       alreadyVisitedUp,
+                                  NodeSet&       alreadyVisitedDn ) const;
+    void __minimalCondSetVisitDn( NodeId         node,
+                                  const NodeSet& soids,
+                                  NodeSet&       minimal,
+                                  NodeSet&       alreadyVisitedUp,
+                                  NodeSet&       alreadyVisitedDn ) const;
   };
 
 
@@ -226,6 +244,6 @@ namespace gum {
 
 } /* namespace gum */
 
-#include <agrum/BN/IBayesNet.tcc>
+#include <agrum/BN/IBayesNet_tpl.h>
 
 #endif /* GUM_SIMPLE_BAYES_NET_H */
