@@ -152,6 +152,6 @@ namespace gum {
 
 } /* namespace gum */
 
-#include <agrum/ID/io/BIFXML/BIFXMLIDReader.tcc>
+#include <agrum/ID/io/BIFXML/BIFXMLIDReader_tpl.h>
 
 #endif  // GUM_BIF_XML_ID_READER_H
