@@ -209,7 +209,7 @@ namespace gum {
 }  // gum
 
 // always include the implementation of the templates
-#include <agrum/PRM/o3prm/O3ClassFactory.tcc>
+#include <agrum/PRM/o3prm/O3ClassFactory_tpl.h>
 
 
 extern template class gum::prm::o3prm::O3ClassFactory<float>;
