@@ -101,7 +101,7 @@ namespace gum {
 }  // gum
 
 // always include the implementation of the templates
-#include <agrum/PRM/o3prm/O3SystemFactory.tcc>
+#include <agrum/PRM/o3prm/O3SystemFactory_tpl.h>
 
 
 extern template class gum::prm::o3prm::O3SystemFactory<float>;
