@@ -169,7 +169,7 @@ namespace gum {
 }  // gum
 
 // always include the implementation of the templates
-#include <agrum/PRM/o3prm/O3prmReader.tcc>
+#include <agrum/PRM/o3prm/O3prmReader_tpl.h>
 
 
 extern template class gum::prm::o3prm::O3prmReader<float>;
