@@ -198,7 +198,7 @@ namespace gum {
 }  // gum
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphicalModels/DAGmodel.inl>
+#include <agrum/graphicalModels/DAGmodel_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_DAGMODEL_H */
