@@ -290,10 +290,10 @@ namespace gum {
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphs/arcGraphPart.inl>
+#include <agrum/graphs/arcGraphPart_inl.h>
 #endif  // GUM_NOINLINE
 
-#include <agrum/graphs/arcGraphPart.tcc>
+#include <agrum/graphs/arcGraphPart_tpl.h>
 
 #endif  // GUM_ARC_GRAPH_PART_H
 // kate: indent-mode cstyle; indent-width 2; replace-tabs on; ;
