@@ -173,7 +173,7 @@ namespace gum {
 
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphs/triangulations/triangulation.inl>
+#include <agrum/graphs/triangulations/triangulation_inl.h>
 #endif  // GUM_NO_INLINE
 
 
