@@ -216,7 +216,7 @@ namespace gum {
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/constraints/structuralConstraintTabuList.inl>
+#include <agrum/learning/constraints/structuralConstraintTabuList_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_LEARNING_STRUCTURAL_TABU_LIST_H */
