@@ -195,6 +195,6 @@ extern template class gum::HashFunc<
 
 
 // always include the template implementation
-#include <agrum/learning/scores_and_tests/idSet.tcc>
+#include <agrum/learning/scores_and_tests/idSet_tpl.h>
 
 #endif /* GUM_LEARNING_ID_SET_H */
