@@ -6,7 +6,7 @@ It provides a high-level interface to the part of aGrUM allowing to create, hand
 The module is generated using the `SWIG <https://www.swig.org>`_ interface generator. Custom-written code was added to make the interface more friendly.
 
 pyAgrum includes :
-  * API documentation, 
+  * API documentation,
   * examples as `notebooks <http://www-desir.lip6.fr/~phw/aGrUM/officiel/notebooks/>`_,
   * a `website <https://forge.lip6.fr/projects/pyagrum/wiki>`_.
 """
@@ -28,7 +28,7 @@ pyAgrum includes :
 #*   Free Software Foundation, Inc.,                                       *
 #*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-__version__ = '0.10.0'
+__version__ = '0.10.3'
 __license__ = __doc__
 __project_url__ = 'http://forge.lip6.fr/projects/pyagrum'
 
@@ -42,14 +42,14 @@ from .pyAgrum import BayesNet
 from .pyAgrum import DiscretizedVariable, LabelizedVariable, RangeVariable, DiscreteVariable
 from .pyAgrum import Potential, Instantiation, UtilityTable
 from .pyAgrum import BruteForceKL, GibbsKL
-from .pyAgrum import GibbsInference, LazyPropagation
+from .pyAgrum import GibbsInference, LazyPropagation, ShaferShenoyInference, VariableElimination
 from .pyAgrum import PythonApproximationListener, PythonBNListener, PythonLoadListener
 from .pyAgrum import BNGenerator, IDGenerator, JTGenerator
 from .pyAgrum import BNLearner
 from .pyAgrum import InfluenceDiagram, InfluenceDiagramInference
 from .pyAgrum import CredalNet, CNMonteCarloSampling, CNLoopyPropagation
 from .pyAgrum import PRMexplorer
-  
+
 from .pyAgrum import initRandom, randomProba, randomDistribution
 from .pyAgrum import isOMP, setNumberOfThreads, getNumberOfLogicalProcessors, getMaxNumberOfThreads
 
@@ -58,26 +58,26 @@ from .pyAgrum import DefaultInLabel, DuplicateElement, DuplicateLabel, EmptyBSTr
 # selection of imports extracted from dir(pyAgrum)
 __all__=[
   '__version__','__license__','__project_url__',        # here
-  'about','availableBNExts','loadBN','saveBN','loadID','getPosterior' # in fuctions.py
-  
+  'about','availableBNExts','loadBN','saveBN','loadID','getPosterior', # in fuctions.py
+
   'Arc','Edge','DiGraph','UndiGraph','MixedGraph','DAG','CliqueGraph',
   'BayesNet',
   'DiscretizedVariable','LabelizedVariable','RangeVariable','DiscreteVariable',
   'Potential','Instantiation','UtilityTable',
   'BruteForceKL','GibbsKL',
-  'GibbsInference','LazyPropagation',
+  'GibbsInference','LazyPropagation','ShaferShenoyInference','VariableElimination',
   'PythonApproximationListener','PythonBNListener','PythonLoadListener',
   'BNGenerator','IDGenerator','JTGenerator',
   'BNLearner',
   'InfluenceDiagram','InfluenceDiagramInference',
-  
+
   'initRandom','randomProba','randomDistribution',
   'isOMP','setNumberOfThreads','getNumberOfLogicalProcessors','getMaxNumberOfThreads',
-  
+
   'CredalNet','CNMonteCarloSampling','CNLoopyPropagation',
-  
+
   'PRMexplorer',
-  
+
   'DefaultInLabel','DuplicateElement','DuplicateLabel','EmptyBSTree','EmptySet','GumException','FatalError','FormatNotFound','GraphError','IOError','IdError','InvalidArc','InvalidArgument','InvalidArgumentsNumber','InvalidDirectedCycle','InvalidEdge','InvalidNode','NoChild','NoNeighbour','NoParent','NotFound','NullElement','OperationNotAllowed','OutOfBounds','OutOfLowerBound','OutOfUpperBound','ReferenceError','SizeError','SyntaxError','UndefinedElement','UndefinedIteratorKey','UndefinedIteratorValue','UnknownLabelInDatabase'
   ]
 
