@@ -23,14 +23,14 @@ Helping functions and consts for pyAgrum
 from .pyAgrum import BayesNet
 from .pyAgrum import Potential
 from .pyAgrum import InfluenceDiagram
-from .pyAgrum import LazyPropagation
+from .pyAgrum import VariableElimination
 
 def about():
   """
   about() for pyAgrum
 
   """
-  print("pyAgrum version {0}".format('0.10.0'))
+  print("pyAgrum version {0}".format('0.10.3'))
   print("(c) Pierre-Henri Wuillemin, Christophe Gonzales, Lionel Torti")
   print("    UPMC 2015")
   print("""
@@ -145,22 +145,26 @@ def fastBN(arcs,domain_size=2):
   bn.generateCPTs()
   return bn
 
-def getPosterior(bn, evs, target):
+def getPosterior(bn, target, evs):
   """
-  Compute the posterior of a single target (variable) in a BN given evidence using Lazy Propagation (for now).
+  Compute the posterior of a single target (variable) in a BN given evidence
+
+
+  getPosterior uses a VariableElimination inference.
+  If more than one target is needed with the same set of evidence or if the same
+  target is needed with more than one set of evidence, this function is not
+  relevant since it creates a new inference engine every time it is called.
 
   :param bn:
   :type bn: pyAgrum.BayesNet
-  :param evs: events map {
-  name;
-  val, name : [ val1, val2 ], ...}
+  :param target: variable name or id
+  :param evs: events map {name/id:val, name/id : [ val1, val2 ], ...}
   :type evs: dictionary
-  :param target: variable name
-  :type target: str
   :return: posterior Potential
   """
-  inf = LazyPropagation(bn)
+  inf = VariableElimination(bn)
   inf.setEvidence(evs)
+  inf.addTarget(target)
   inf.makeInference()
-  return Potential(inf.posterior(bn.idFromName(target)))
+  return Potential(inf.posterior(target))
 #creating a new Potential from posterior( will disappear with ie )
